parse_tokens

Function parse_tokens 

pub fn parse_tokens(
    lexer: impl TokenIterator,
    entrypoint: Token,
) -> Result<ParseEntryPoint, Error>
Parse a token stream into a syntax tree.

Low-level implementation, you probably don’t want to use this. See parse_str.

The entrypoint parameter must be one of the EntryPointXXX tokens, which tells the parser which syntax node to expect. It returns the ParseEntryPoint union type.