AddressSpace

Enum AddressSpace 

pub enum AddressSpace {
    Function,
    Private,
    Workgroup,
    Uniform,
    Storage,
    Handle,
    Immediate,
    TaskPayload,
    RayPayload,
    IncomingRayPayload,
}
Address space enumeration.

Reference: https://www.w3.org/TR/WGSL/#address-spaces

Variants



Function



Private



Workgroup



Uniform



Storage



Handle



Immediate



TaskPayload

Available on crate feature naga-ext only.


RayPayload

Available on crate feature naga-ext only.

Ray tracing pipeline payload, passed to traceRay.



IncomingRayPayload

Available on crate feature naga-ext only.

Ray tracing pipeline payload, received by entry points invoked by traceRay.

An entry point may reference at most one variable in this address space.

Implementations