Attribute

Enum Attribute 

pub enum Attribute {
Show 27 variants Align(ExpressionNode), Binding(ExpressionNode), BlendSrc(ExpressionNode), Builtin(BuiltinValue), Const, Diagnostic(DiagnosticAttribute), Group(ExpressionNode), Id(ExpressionNode), Interpolate(InterpolateAttribute), Invariant, Location(ExpressionNode), MustUse, Size(ExpressionNode), WorkgroupSize(WorkgroupSizeAttribute), Vertex, Fragment, Compute, Task, Payload(ExpressionNode), Mesh(ExpressionNode), Publish, If(ExpressionNode), Elif(ExpressionNode), Else, Type(TypeConstraint), EarlyDepthTest(Option<ConservativeDepth>), Custom(CustomAttribute),
}

Variants



Align(ExpressionNode)



Binding(ExpressionNode)



BlendSrc(ExpressionNode)



Builtin(BuiltinValue)



Const



Diagnostic(DiagnosticAttribute)



Group(ExpressionNode)



Id(ExpressionNode)



Interpolate(InterpolateAttribute)



Invariant



Location(ExpressionNode)



MustUse



Size(ExpressionNode)



WorkgroupSize(WorkgroupSizeAttribute)



Vertex



Fragment



Compute



Task

Available on crate feature naga-ext only.


Payload(ExpressionNode)

Available on crate feature naga-ext only.


Mesh(ExpressionNode)

Available on crate feature naga-ext only.


Publish

Available on crate feature imports only.


If(ExpressionNode)

Available on crate feature condcomp only.


Elif(ExpressionNode)

Available on crate feature condcomp only.


Else

Available on crate feature condcomp only.


Type(TypeConstraint)

Available on crate feature generics only.


EarlyDepthTest(Option<ConservativeDepth>)

Available on crate feature naga-ext only.


Custom(CustomAttribute)

Implementations

Source

impl Attribute

pub const fn is_align(&self) -> bool

Returns true if this value is of type Align. Returns false otherwise

pub const fn is_binding(&self) -> bool

Returns true if this value is of type Binding. Returns false otherwise

pub const fn is_blend_src(&self) -> bool

Returns true if this value is of type BlendSrc. Returns false otherwise

pub const fn is_builtin(&self) -> bool

Returns true if this value is of type Builtin. Returns false otherwise

pub const fn is_const(&self) -> bool

Returns true if this value is of type Const. Returns false otherwise

pub const fn is_diagnostic(&self) -> bool

Returns true if this value is of type Diagnostic. Returns false otherwise

pub const fn is_group(&self) -> bool

Returns true if this value is of type Group. Returns false otherwise

pub const fn is_id(&self) -> bool

Returns true if this value is of type Id. Returns false otherwise

pub const fn is_interpolate(&self) -> bool

Returns true if this value is of type Interpolate. Returns false otherwise

pub const fn is_invariant(&self) -> bool

Returns true if this value is of type Invariant. Returns false otherwise

pub const fn is_location(&self) -> bool

Returns true if this value is of type Location. Returns false otherwise

pub const fn is_must_use(&self) -> bool

Returns true if this value is of type MustUse. Returns false otherwise

pub const fn is_size(&self) -> bool

Returns true if this value is of type Size. Returns false otherwise

pub const fn is_workgroup_size(&self) -> bool

Returns true if this value is of type WorkgroupSize. Returns false otherwise

pub const fn is_vertex(&self) -> bool

Returns true if this value is of type Vertex. Returns false otherwise

pub const fn is_fragment(&self) -> bool

Returns true if this value is of type Fragment. Returns false otherwise

pub const fn is_compute(&self) -> bool

Returns true if this value is of type Compute. Returns false otherwise

pub const fn is_task(&self) -> bool

Returns true if this value is of type Task. Returns false otherwise

pub const fn is_payload(&self) -> bool

Returns true if this value is of type Payload. Returns false otherwise

pub const fn is_mesh(&self) -> bool

Returns true if this value is of type Mesh. Returns false otherwise

pub const fn is_publish(&self) -> bool

Returns true if this value is of type Publish. Returns false otherwise

pub const fn is_if(&self) -> bool

Returns true if this value is of type If. Returns false otherwise

pub const fn is_elif(&self) -> bool

Returns true if this value is of type Elif. Returns false otherwise

pub const fn is_else(&self) -> bool

Returns true if this value is of type Else. Returns false otherwise

pub const fn is_type(&self) -> bool

Returns true if this value is of type Type. Returns false otherwise

pub const fn is_early_depth_test(&self) -> bool

Returns true if this value is of type EarlyDepthTest. Returns false otherwise

pub const fn is_custom(&self) -> bool

Returns true if this value is of type Custom. Returns false otherwise

Source

impl Attribute

pub fn unwrap_align(self) -> ExpressionNode

Unwraps this value to the Attribute::Align variant. Panics if this value is of any other type.

pub fn unwrap_binding(self) -> ExpressionNode

Unwraps this value to the Attribute::Binding variant. Panics if this value is of any other type.

pub fn unwrap_blend_src(self) -> ExpressionNode

Unwraps this value to the Attribute::BlendSrc variant. Panics if this value is of any other type.

pub fn unwrap_builtin(self) -> BuiltinValue

Unwraps this value to the Attribute::Builtin variant. Panics if this value is of any other type.

pub fn unwrap_const(self)

Unwraps this value to the Attribute::Const variant. Panics if this value is of any other type.

pub fn unwrap_diagnostic(self) -> DiagnosticAttribute

Unwraps this value to the Attribute::Diagnostic variant. Panics if this value is of any other type.

pub fn unwrap_group(self) -> ExpressionNode

Unwraps this value to the Attribute::Group variant. Panics if this value is of any other type.

pub fn unwrap_id(self) -> ExpressionNode

Unwraps this value to the Attribute::Id variant. Panics if this value is of any other type.

pub fn unwrap_interpolate(self) -> InterpolateAttribute

Unwraps this value to the Attribute::Interpolate variant. Panics if this value is of any other type.

pub fn unwrap_invariant(self)

Unwraps this value to the Attribute::Invariant variant. Panics if this value is of any other type.

pub fn unwrap_location(self) -> ExpressionNode

Unwraps this value to the Attribute::Location variant. Panics if this value is of any other type.

pub fn unwrap_must_use(self)

Unwraps this value to the Attribute::MustUse variant. Panics if this value is of any other type.

pub fn unwrap_size(self) -> ExpressionNode

Unwraps this value to the Attribute::Size variant. Panics if this value is of any other type.

pub fn unwrap_workgroup_size(self) -> WorkgroupSizeAttribute

Unwraps this value to the Attribute::WorkgroupSize variant. Panics if this value is of any other type.

pub fn unwrap_vertex(self)

Unwraps this value to the Attribute::Vertex variant. Panics if this value is of any other type.

pub fn unwrap_fragment(self)

Unwraps this value to the Attribute::Fragment variant. Panics if this value is of any other type.

pub fn unwrap_compute(self)

Unwraps this value to the Attribute::Compute variant. Panics if this value is of any other type.

pub fn unwrap_task(self)

Unwraps this value to the Attribute::Task variant. Panics if this value is of any other type.

pub fn unwrap_payload(self) -> ExpressionNode

Unwraps this value to the Attribute::Payload variant. Panics if this value is of any other type.

pub fn unwrap_mesh(self) -> ExpressionNode

Unwraps this value to the Attribute::Mesh variant. Panics if this value is of any other type.

pub fn unwrap_publish(self)

Unwraps this value to the Attribute::Publish variant. Panics if this value is of any other type.

pub fn unwrap_if(self) -> ExpressionNode

Unwraps this value to the Attribute::If variant. Panics if this value is of any other type.

pub fn unwrap_elif(self) -> ExpressionNode

Unwraps this value to the Attribute::Elif variant. Panics if this value is of any other type.

pub fn unwrap_else(self)

Unwraps this value to the Attribute::Else variant. Panics if this value is of any other type.

pub fn unwrap_type(self) -> TypeConstraint

Unwraps this value to the Attribute::Type variant. Panics if this value is of any other type.

pub fn unwrap_early_depth_test(self) -> Option<ConservativeDepth>

Unwraps this value to the Attribute::EarlyDepthTest variant. Panics if this value is of any other type.

pub fn unwrap_custom(self) -> CustomAttribute

Unwraps this value to the Attribute::Custom variant. Panics if this value is of any other type.

Source

impl Attribute

pub fn is_entry_point(&self) -> bool

pub fn is_condcomp(&self) -> bool

Available on crate feature condcomp only.