CaseSelector

Enum CaseSelector 

pub enum CaseSelector {
    Default,
    Expression(ExpressionNode),
}

Variants



Default



Expression(ExpressionNode)

Implementations

Source

impl CaseSelector

pub const fn is_default(&self) -> bool

Returns true if this value is of type Default. Returns false otherwise

pub const fn is_expression(&self) -> bool

Returns true if this value is of type Expression. Returns false otherwise

Source

impl CaseSelector

pub fn unwrap_default(self)

Unwraps this value to the CaseSelector::Default variant. Panics if this value is of any other type.

pub fn unwrap_expression(self) -> ExpressionNode

Unwraps this value to the CaseSelector::Expression variant. Panics if this value is of any other type.