ImportContent

Enum ImportContent 

pub enum ImportContent {
    Item(ImportItem),
    Collection(Vec<Import>),
}
Available on crate feature imports only.

Variants



Item(ImportItem)



Collection(Vec<Import>)

Implementations

Source

impl ImportContent

pub const fn is_item(&self) -> bool

Returns true if this value is of type Item. Returns false otherwise

pub const fn is_collection(&self) -> bool

Returns true if this value is of type Collection. Returns false otherwise