PathOrigin

Enum PathOrigin 

pub enum PathOrigin {
    Absolute,
    Relative(usize),
    Package(String),
}
Available on crate feature imports only.

Variants



Absolute

Import relative to the current package root, starting with ‘package::’.



Relative(usize)

Import relative to the current module, starting with ‘super::’. The usize is the number of ’super’s.



Package(String)

Import from a package dependency, starting with the extern package name.

Implementations

Source

impl PathOrigin

pub const fn is_absolute(&self) -> bool

Returns true if this value is of type Absolute. Returns false otherwise

pub const fn is_relative(&self) -> bool

Returns true if this value is of type Relative. Returns false otherwise

pub const fn is_package(&self) -> bool

Returns true if this value is of type Package. Returns false otherwise